<template>
    <div class="equity-registration-warehousing corporate-customers">
        <!-- 左侧树 -->
        <div class="left-tree">
            <tree-side
                :treeData="treeData"
                :tabList="tabList"
                :defaultProps="defaultProps"
                @currentChange="currentChange"
                @tabChange="tabChange"
                @filterChange="filterChange"
            ></tree-side>
        </div>
        <div class="right-table" v-loading="tableLoading">
            <div class="full-page bg">
            <div class="chart-content">
                <div id="chartDom"></div>
            </div>
            </div>
        </div>
        </editAddDialog>
    </div>
</template>

<script>
import * as echarts from 'echarts'
console.log(echarts)
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import utils from '@/utils.js'
import SuperSearch from '@/components/SuperSearch/index.vue'
import api from '@/api/InvestmentFinancingAssets/InvestmentFinancingEnter/EquityRelationshipMap.js'
import treeSide from '@/components/treeSide/index.vue'
export default {
    name: 'EquityRelationshipMap', // 股权关系图谱
    components: {
        SuperSearch,
        pagination,
        treeSide,
    },
    mixins: [TableMixin],
    data() {
        return {
            tableLoading: false,
            tabList: ['单位'], //左边tab
            defaultProps: {
                children: 'children',
                label: 'name',
            },
            dataList: [],
            nodeList: [],
            linkList: [],
            treeData: [],
            loading: false,
            queryParams: {
                orgId: null,
                orgName: null,
            },
        }
    },
    created() {
        // let curUserDetail = this.$store.state.user.currentUserDetail
        // this.queryParams.orgId = curUserDetail.org[0].orgId
        // this.queryParams.orgName = curUserDetail.org[0].orgName
        this.getUserOrgTree()
    },
    mounted() {
        this.loadData()
    },
    methods: {
        // node数据处理
        nodeProcessing(data) {
            const result = []
            function traverse(node, level) {
                const name = node.name
                const id = node.id
                result.push({name, level, id})
                if (node.list && node.list.length > 0) {
                    node.list.forEach((childNode) => {
                        traverse(childNode, childNode.level)
                    })
                }
            }
            traverse(data, data.level)
            return result
        },
        // link数据处理
        linkProcessing(data) {
            const result = []
            function traverse(node, parentId) {
                const id = node.id
                const type = node.type
                const equityRatio = node.equityRatio

                if (type === 2) {
                    result.push({
                        source: parentId,
                        target: id,
                        eq: `持股${equityRatio}%`,
                    })
                } else if (type === 1) {
                    result.push({
                        source: id,
                        target: parentId,
                        eq: `持股${equityRatio}%`,
                    })
                }

                if (node.list && node.list.length > 0) {
                    node.list.forEach((childNode) => {
                        traverse(childNode, id)
                    })
                }
            }
            traverse(data, '')
            return result
        },
        initChat() {
            let chartDom = echarts.init(document.getElementById('chartDom'))
            const color1 = '#006acc'
            const color2 = '#e7b178'
            const color3 = '#96e9be'

            this.nodeList.forEach((node) => {
                if (node.level === 1) {
                    node.symbolSize = 140
                    node.itemStyle = {
                        color: color1,
                    }
                } else if (node.level === 2) {
                    node.symbolSize = 120
                    node.itemStyle = {
                        color: color2,
                    }
                } else if (node.level === 3) {
                    node.symbolSize = 100
                    node.itemStyle = {
                        color: color3,
                    }
                }
            })
            this.linkList.forEach((link, index) => {
                // link.id = index

                link.label = {
                    align: 'center',
                    fontSize: 16,
                    color: '#000',
                    offset: [0, -5], // 微调文字位置，根据需要调整偏移量
                }
                link.lineStyle = {
                    color: color2,
                    curveness: 0.3,
                }
            })
            let option = {
                title: {
                    text: '股权关系图谱',
                },
                series: [
                    {
                        type: 'graph',
                        layout: 'force',
                        symbolSize: 20,
                        draggable: true,
                        roam: true,
                        focusNodeAdjacency: true,
                        edgeSymbol: ['', 'arrow'],
                        edgeSymbolSize: [15, 15],
                        edgeLabel: {
                            normal: {
                                show: true,
                                textStyle: {
                                    fontSize: 20,
                                },
                                formatter(x) {
                                    return x.data.eq
                                },
                            },
                        },
                        label: {
                            show: true,
                            fontSize: 16,
                            formatter: function (params) {
                                console.log(params)
                                var name = params.name
                                // 将字符串按照每 10 个字符进行分割，并插入换行符
                                var nameArr = []
                                if (params.data.level === 1) {
                                    nameArr = name.match(/.{1,10}/g)
                                } else if (params.data.level === 2) {
                                    nameArr = name.match(/.{1,8}/g)
                                } else if (params.data.level === 3) {
                                    nameArr = name.match(/.{1,6}/g)
                                }
                                return nameArr.join('\n')
                            },
                        },
                        force: {
                            repulsion: 2000,
                            edgeLength: 120,
                        },
                        data: this.nodeList,
                        links: this.linkList,
                    },
                ],
            }
            chartDom.setOption(option)
            console.log(option)
            window.addEventListener('resize', () => {
                chartDom.resize()
            })
        },
        //获取数据
        loadData() {
            this.tableLoading = true
            this.nodeList = []
            this.linkList = []
            api.queryData(this.queryParams, (res) => {
                this.dataList = [res]
                this.linkList = this.linkProcessing(res)
                this.nodeList = this.nodeProcessing(res)
                this.tableLoading = false
                this.initChat()
            })
        },
        currentChange(value, data) {
            if (value) {
                this.queryParams.orgId = value.id
                this.queryParams.orgName = value.name
            } else {
                this.queryParams.orgId = null
                this.queryParams.orgName = null
            }
            this.loadData()
        },
        tabChange(tab, event) {
            console.log(tab)
        },
        filterChange(value) {},
        //获取组织树
        getUserOrgTree() {
            let curUserDetail = this.$store.state.user.currentUserDetail
            let orgId = curUserDetail.org[0].orgId
            api.getUserOrgTree(orgId, (res) => {
                if (res) {
                    this.treeData = res
                }
            })
        },
    },
}
</script>

<style scoped lang="scss">
.equity-registration-warehousing {
    width: 100%;
    display: flex;
    .left-tree {
        margin: 16px 0 0 24px;
    }
    .right-table {
        width: calc(100% - 324px);
    }
}
.search-box {
    //height: 350px;
    padding: 20px 30px;
    transition: all 1s;
    background-color: #ffffff;
    border-radius: 8px;
}

.table-content {
    width: 100%;
    height: calc(100% - 110px);

    .table-list {
        width: 100%;
        height: 100%;
    }
}

/deep/ .el-table .el-table__header th {
    padding: 12px 0 !important;
    background-color: #f1f5f8 !important;
}

/deep/ .el-table .el-table__header th .cell {
    font-size: 16px;
    color: #545454;
    font-weight: 700;
    font-family: PingFang SC-Medium, PingFang SC;
    white-space: nowrap;
}

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(2) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}
/deep/ .full-page {
    padding-left: 16px !important;
}
::v-deep .el-icon-s-check {
    font-size: 14px;
}
.chart-content {
    flex: 1;
    height: calc(100% - 16px);
    padding: 10px 16px;
    background: #ffffff;
    box-sizing: border-box;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;
    overflow: hidden;
    #chartDom {
        width: 100%;
        height: 100%;
    }
}
</style>

